summaryrefslogtreecommitdiffstats
path: root/kmail/editorwatcher.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/editorwatcher.h')
-rw-r--r--kmail/editorwatcher.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kmail/editorwatcher.h b/kmail/editorwatcher.h
index 839386f8..35504d85 100644
--- a/kmail/editorwatcher.h
+++ b/kmail/editorwatcher.h
@@ -43,11 +43,11 @@ class EditorWatcher : public QObject
* Constructs an EditorWatcher.
* @param parent the parent object of this EditorWatcher, which will take care of deleting
* this EditorWatcher if the parent is deleted.
* @param parentWidget the parent widget of this EditorWatcher, which will be used as the parent
* widget for message dialogs.
*/
EditorWatcher( const KURL &url, const TQString &mimeType, bool openWith,
- TQObject *parent, TQWidget *parentWidget );
+ TQObject *parent, TQWidget *tqparentWidget );
bool start();
bool fileChanged() const { return mFileModified; }
signals:
@@ -43,11 +43,11 @@ class EditorWatcher : public QObject
* @param parent the parent object of this EditorWatcher, which will take care of deleting
* this EditorWatcher if the parent is deleted.
- * @param parentWidget the parent widget of this EditorWatcher, which will be used as the parent
+ * @param tqparentWidget the parent widget of this EditorWatcher, which will be used as the parent
* widget for message dialogs.
*/